@@ -95,7 +95,7 @@ ee_photos <- function(page = NULL,
 	main_args$page <- as.character(page)
 
 	data_sources <- GET(photos_url, query = args, foptions)
-    warn_for_status(data_sources)
+    warn_for_status(data_sources, "Web resource is currently unavailable. Please try again later")
     photos <- content(data_sources, type = "application/json")
 	required_pages <- ee_paginator(page = page, total_obs = photos$count, page_size)
 
