@@ -12,7 +12,7 @@ ee_sources <- function(foptions = list()) {
 	# base_url <- "http://ecoengine.berkeley.edu/api/sources/?format=json"
 	base_url <- paste0(ee_base_url(), "sources/?format=json")
     data_sources <- GET(base_url, foptions)
-    warn_for_status(data_sources)
+    warn_for_status(data_sources, "Web resource is currently unavailable. Please try again later")
     ds <- content(data_sources, type = "application/json")
     # Fix to remove ldply
     sources <- ldply(ds$results, function(x) data.frame(x))
